/* Copyright (C) 1997 Oracle Corp.  All rights reserved. */

package oracle.help.demo;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Cursor;
import java.awt.Image;
import java.awt.Menu;
import java.awt.MenuBar;
import java.awt.MenuItem;
import java.awt.MenuShortcut;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.net.URL;

import oracle.ewt.imageCanvas.ImageCanvas;
import oracle.ewt.lwAWT.BufferedFrame;
import oracle.ewt.toolBar.ToolBar;
import oracle.ewt.toolBar.ToolBarActionListener;
import oracle.ewt.toolBar.ToolBarButton;
import oracle.ewt.toolBar.ToolBarEvent;
import oracle.ewt.toolBar.ToolBarItem;
import oracle.ewt.toolBar.ToolBarMouseListener;
import oracle.ewt.toolBar.ToolBarSeparator;
import oracle.ewt.util.WindowUtils;

import oracle.help.HelpManager;
import oracle.help.Help;
import oracle.help.Book;

import oracle.help.util.Canonicalizer;

public class DemoMain extends BufferedFrame
  implements ToolBarActionListener, ToolBarMouseListener, ActionListener
{
  public static void main(String[] args)
  {
    DemoMain main = new DemoMain();
    main.setVisible(true);
  }

  public DemoMain()
  {
    super("Oracle Discoverer");

    try
    {
      String basestring = "file:";
      String separator = System.getProperty("file.separator");
      if (separator.equals("\\"))
        basestring = "file:/";
      basestring = basestring + System.getProperty("install.root");
      basestring = Canonicalizer.fixPathname(basestring);
      basestring = basestring.concat("demodoc/");

      // create the book and add it as the default book to HelpManager
      Book book = 
       Help.createBook(basestring, "discoverer", "Oracle Discoverer");
      helpManager.addBook(book, true);
    }
    catch (Exception e)
    {
      System.err.println("Failed while initializing help");
      e.printStackTrace();
      System.exit(0);
    }

    setBackground(Color.lightGray);
    setLayout(new BorderLayout());
    
    _toolbar = new ToolBar();
    _toolbar.addToolBarMouseListener(this);

    _loginImage = ImageLoader.loadImage(this, "images/login.gif");
    _loginSelImage = ImageLoader.loadImage(this, "images/sel_login.gif");
    _openImage = ImageLoader.loadImage(this, "images/open.gif");
    _openSelImage = ImageLoader.loadImage(this, "images/sel_open.gif");
    _refreshImage = ImageLoader.loadImage(this, "images/refresh.gif");
    _refreshSelImage = ImageLoader.loadImage(this, "images/sel_refresh.gif");
    _optionImage = ImageLoader.loadImage(this, "images/options.gif");
    _optionSelImage = ImageLoader.loadImage(this, "images/sel_options.gif");
    _aboutImage = ImageLoader.loadImage(this, "images/about.gif");
    _aboutSelImage = ImageLoader.loadImage(this, "images/sel_about.gif");
    _helpImage = ImageLoader.loadImage(this, "images/help.gif");
    _helpSelImage = ImageLoader.loadImage(this, "images/sel_help.gif");

    _loginButton = new ToolBarButton(LOGINBUTTON, _loginImage);
    _openButton = new ToolBarButton(OPENBUTTON, _openImage);
    _refreshButton = new ToolBarButton(REFRESHBUTTON, _refreshImage);
    _optionButton = new ToolBarButton(OPTIONBUTTON, _optionImage);
    _helpButton = new ToolBarButton(HELPBUTTON, _helpImage);
    _aboutButton = new ToolBarButton(ABOUTBUTTON, _aboutImage);

    _toolbar.addItem(_loginButton);
    _toolbar.addItem(_openButton);
    _toolbar.addItem(_refreshButton);
    _toolbar.addItem(_optionButton);
    _toolbar.addItem(_helpButton);
    _toolbar.addItem(_aboutButton);

    _loginButton.addToolBarActionListener(this);
    _openButton.addToolBarActionListener(this);
    _refreshButton.addToolBarActionListener(this);
    _optionButton.addToolBarActionListener(this);
    _helpButton.addToolBarActionListener(this);
    _aboutButton.addToolBarActionListener(this);

    _loginButton.setEnabled(false);
    _openButton.setEnabled(false);
    _refreshButton.setEnabled(false);
    _optionButton.setEnabled(true);
    _helpButton.setEnabled(true);
    _aboutButton.setEnabled(false);

    add(_toolbar, BorderLayout.NORTH);

    Image canvasImage = ImageLoader.loadImage(this, "images/canvas.gif");
    ImageCanvas canvas = new ImageCanvas(canvasImage);

    add(canvas);

    addWindowListener(
      new WindowAdapter() 
      {
        public void windowClosing(WindowEvent e)
        {
          {
            setVisible(false);
            System.exit(0);
          }
        }
      }
    );

    MenuBar menubar = new MenuBar();
 
    // File menu
    Menu    filemenu    =  new Menu("File");
    MenuItem tempItem = new MenuItem("New", new MenuShortcut(KeyEvent.VK_N));
    tempItem.setEnabled(false);
    filemenu.add(tempItem);
    tempItem = new MenuItem("Open", new MenuShortcut(KeyEvent.VK_O));
    tempItem.setEnabled(false);
    filemenu.add(tempItem);
    tempItem = new MenuItem("Close");
    tempItem.setEnabled(false);
    filemenu.add(tempItem);
    filemenu.addSeparator();
    tempItem = new MenuItem("Save", new MenuShortcut(KeyEvent.VK_S));
    tempItem.setEnabled(false);
    filemenu.add(tempItem);    
    filemenu.addSeparator();
    _exitMenuItem = new MenuItem("Exit");
    filemenu.add(_exitMenuItem);
    _exitMenuItem.addActionListener(this);
    menubar.add(filemenu);

    // Edit menu
    Menu editmenu = new Menu("Edit");
    MenuItem undoItem = new MenuItem("Undo", new MenuShortcut(KeyEvent.VK_Z));
    undoItem.setEnabled(false);
    editmenu.add(undoItem);
    editmenu.addSeparator();
    MenuItem cutItem = new MenuItem("Cut", new MenuShortcut(KeyEvent.VK_X));
    cutItem.setEnabled(false);
    editmenu.add(cutItem);
    MenuItem copyItem = new MenuItem("Copy", new MenuShortcut(KeyEvent.VK_C));
    copyItem.setEnabled(false);
    editmenu.add(copyItem);
    MenuItem pasteItem = new MenuItem("Paste",
                                      new MenuShortcut(KeyEvent.VK_V));
    pasteItem.setEnabled(false);
    editmenu.add(pasteItem);
    menubar.add(editmenu);

    // Parameters menu
    Menu paramMenu = new Menu("Parameters");
    _newParamMenuItem = new MenuItem("New...");
    _newParamMenuItem.addActionListener(this);
    paramMenu.add(_newParamMenuItem);
    MenuItem editParamItem = new MenuItem("Edit...");
    editParamItem.setEnabled(false);
    paramMenu.add(editParamItem);
    MenuItem deleteParamItem = new MenuItem("Delete");
    deleteParamItem.setEnabled(false);
    paramMenu.add(deleteParamItem);
    menubar.add(paramMenu);

    // Sheet menu
    Menu sheetMenu = new Menu("Sheet");
    tempItem = new MenuItem("New Sheet...");
    tempItem.setEnabled(false);
    sheetMenu.add(tempItem);
    tempItem = new MenuItem("Edit Sheet...");
    tempItem.setEnabled(false);
    sheetMenu.add(tempItem);
    tempItem = new MenuItem("Duplicate as Table...");
    tempItem.setEnabled(false);
    sheetMenu.add(tempItem);
    tempItem = new MenuItem("Duplicate as Crosstab...");
    tempItem.setEnabled(false);
    sheetMenu.add(tempItem);
    sheetMenu.addSeparator();
    tempItem = new MenuItem("Rename Sheet...");
    tempItem.setEnabled(false);
    sheetMenu.add(tempItem);
    tempItem = new MenuItem("Delete Sheet...");
    tempItem.setEnabled(false);
    sheetMenu.add(tempItem);
    tempItem = new MenuItem("Edit Title...");
    tempItem.setEnabled(false);
    sheetMenu.add(tempItem);
    menubar.add(sheetMenu);

    // Format menu
    Menu formatMenu = new Menu("Format");
    tempItem = new MenuItem("Data...");
    tempItem.setEnabled(false);
    formatMenu.add(tempItem);
    tempItem = new MenuItem("Headings...");
    tempItem.setEnabled(false);
    formatMenu.add(tempItem);
    tempItem = new MenuItem("Exceptions...");
    tempItem.setEnabled(false);
    formatMenu.add(tempItem);
    menubar.add(formatMenu);
 
    // Help menu
    Menu helpmenu = new Menu("Help");
    _contentsMenuItem = new MenuItem("Help Contents");
    _contentsMenuItem.addActionListener(this);
    helpmenu.add(_contentsMenuItem);
    _indexMenuItem    = new MenuItem("Topic Index");
    _indexMenuItem.addActionListener(this);
    helpmenu.add(_indexMenuItem);
    _searchMenuItem   = new MenuItem("Full Text Search");
    _searchMenuItem.addActionListener(this);
    helpmenu.add(_searchMenuItem);
    menubar.setHelpMenu(helpmenu);
 
    setMenuBar(menubar);    

    pack();
    pack();
  }

  /**
   * Returns the HelpManager of this application.
   */
  public static HelpManager getHelpManager()
  {
    return helpManager;
  }

  public void toolBarItemActionPerformed(ToolBarEvent e)
  {
    int id = e.getItem().getID();

    switch(id)
    {
    case OPTIONBUTTON:
      if (_paramDialog == null)
      {
        _paramDialog = new ParamDialog(this);
        WindowUtils.centerWindow(_paramDialog, this);
      }
      _paramDialog.setVisible(true);
      break;

    case HELPBUTTON:
      helpManager.showContents();
      break;
    }
  }

  public void toolBarItemMouseEntered(ToolBarEvent e)
  {
    ToolBarItem item = e.getItem();
    int id = item.getID();

    if (!item.isEnabled())
      return;

    switch(id)
    {
    case LOGINBUTTON:
      _loginButton.setIcon(_loginSelImage);
      break;

    case OPENBUTTON:
      _openButton.setIcon(_openSelImage);
      break;

    case REFRESHBUTTON:
      _refreshButton.setIcon(_refreshSelImage);
      break;

    case OPTIONBUTTON:
      _optionButton.setIcon(_optionSelImage);
      break;

    case HELPBUTTON:
      _helpButton.setIcon(_helpSelImage);
      break;
      
    case ABOUTBUTTON:
      _aboutButton.setIcon(_aboutSelImage);
      break;
    }
  }

  public void toolBarItemMouseExited(ToolBarEvent e)
  {
    ToolBarItem item = e.getItem();
    int id = item.getID();

    if (!item.isEnabled())
      return;

    switch(id)
    {
    case LOGINBUTTON:
      _loginButton.setIcon(_loginImage);
      break;

    case OPENBUTTON:
      _openButton.setIcon(_openImage);
      break;

    case REFRESHBUTTON:
      _refreshButton.setIcon(_refreshImage);
      break;

    case OPTIONBUTTON:
      _optionButton.setIcon(_optionImage);
      break;

    case HELPBUTTON:
      _helpButton.setIcon(_helpImage);
      break;
      
    case ABOUTBUTTON:
      _aboutButton.setIcon(_aboutImage);
      break;
    }
  }

  public void actionPerformed(ActionEvent e)
  {
    Object source = e.getSource();

    if (source == _exitMenuItem)
      System.exit(0);

    if (source == _contentsMenuItem)
    {
      setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
      helpManager.showContents();
      setCursor(Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR));
    }
    else if (source == _indexMenuItem)
    {
      setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
      helpManager.showIndex();
      setCursor(Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR));
    }
    else if (source == _searchMenuItem)
    { 
      setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
      helpManager.showSearch();
      setCursor(Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR));
    }
    else if (source == _newParamMenuItem)
    {
      if (_paramDialog == null)
      {
        _paramDialog = new ParamDialog(this);
        WindowUtils.centerWindow(_paramDialog, this);
      }
      _paramDialog.setVisible(true);
    }      
  }
    
  // instance variables
  public final  static HelpManager  helpManager
                                        = new HelpManager(new Help());

  private final static int LOGINBUTTON = 1;
  private final static int OPENBUTTON = 2;
  private final static int REFRESHBUTTON = 3;
  private final static int OPTIONBUTTON = 4;
  private final static int HELPBUTTON = 5;
  private final static int ABOUTBUTTON = 6;

  private Image _loginImage;
  private Image _loginSelImage;
  private Image _openImage;
  private Image _openSelImage;
  private Image _refreshImage;
  private Image _refreshSelImage;
  private Image _optionImage;
  private Image _optionSelImage;
  private Image _helpImage;
  private Image _helpSelImage;
  private Image _aboutImage;
  private Image _aboutSelImage;

  private ToolBarButton _loginButton;
  private ToolBarButton _openButton;
  private ToolBarButton _refreshButton;
  private ToolBarButton _optionButton;
  private ToolBarButton _helpButton;
  private ToolBarButton _aboutButton;

  private ToolBar _toolbar;

  private ParamDialog _paramDialog;

  private MenuItem _exitMenuItem;
  private MenuItem _contentsMenuItem, _searchMenuItem, _indexMenuItem;
  private MenuItem _newParamMenuItem;
} 
